Expands factors into the full factorial and renders the vignette text
per cell with literal {factor} substitution. Each rendered vignette is
typically paired with one or two items via panel_instrument().
Expands factors into the full factorial and renders the vignette text
per cell with literal {factor} substitution. Each rendered vignette is
typically paired with one or two items via panel_instrument().